@@ -1,7 +1,7 @@
 #ifndef NEUTRINO_WINDOW_PRIVATE_H
 #define NEUTRINO_WINDOW_PRIVATE_H
 
-#include <gtk/gtkliststore.h>
+#include <gtk/gtk.h>
 
 #include "neutrino-window.h"
 
@@ -9,11 +9,6 @@
 
 #include "neutrino-file-browser.h"
 
-#include "libegg/menu/egg-menu-merge.h"
-#include "libegg/menu/egg-action-group.h"
-#include "libegg/menu/egg-toggle-action.h"
-#include "libegg/toolbar/eggtoolbar.h"
-
 enum {
 	NEUTRINO_VIEW_NONE = 0,
 	NEUTRINO_VIEW_JUKEBOX,
@@ -31,8 +26,8 @@ enum {
 struct NeutrinoWindowDetails
 {
 	/* ui stuff */
-	EggActionGroup *group;
-	EggMenuMerge *merge;
+	GtkActionGroup *group;
+	GtkUIManager *merge;
 
 	NeutrinoJukeboxView *view;
 	NeutrinoFileBrowser *browser;
