@@ -11,7 +11,6 @@ typedef enum {
 	DELETE_TRACKS,
 	SET_METADATA,
 
-	GET_EAX,
 	SET_EAX,
 
 	PLAY_TRACK,
@@ -35,6 +34,7 @@ typedef enum {
 typedef struct {
 	NomadJukeboxJobType type;
 
+	guint id;
 	guint priority;
 
 	/* so we can pass some data in, a list for example,
