@@ -40,24 +40,21 @@ static void neutrino_jukebox_view_add_initial_tracks( gpointer key,
 
 
 static void neutrino_jukebox_view_add_track( NomadJukebox *jukebox,
-					     guint total_tracks,
-					     const NomadTrack *track,
-					     NeutrinoJukeboxView *view );
+		guint jobid, guint total_tracks,
+		const NomadTrack *track, NeutrinoJukeboxView *view );
 static void neutrino_jukebox_view_remove_track( NomadJukebox *jukebox,
-						const NomadTrack *track,
-						NeutrinoJukeboxView *view );
+		guint jobid, const NomadTrack *track,
+		NeutrinoJukeboxView *view );
 static void neutrino_jukebox_view_change_track( NomadJukebox *jukebox,
-						const NomadTrack *orig,
-						const NomadTrack *track,
-						NeutrinoJukeboxView *view );
+		guint jobid, const NomadTrack *orig,
+		const NomadTrack *track, NeutrinoJukeboxView *view );
 
 static void neutrino_jukebox_view_add_playlist( NomadJukebox *jukebox,
-						guint total_tracks,
-						const gchar *name,
-						NeutrinoJukeboxView *view );
+		guint jobid, guint total_tracks, const gchar *name, 
+		NeutrinoJukeboxView *view );
 static void neutrino_jukebox_view_remove_playlist( NomadJukebox *jukebox,
-						   const gchar *name,
-						   NeutrinoJukeboxView *view );
+		guint jobid, const gchar *name,
+		NeutrinoJukeboxView *view );
 
 static void neutrino_jukebox_view_add_artist( NeutrinoJukeboxView *view, 
 					 const NomadTrack *track );
@@ -336,9 +333,8 @@ gboolean neutrino_jukebox_view_search( NeutrinoJukeboxView *view,
 /* static funcs */
 
 static void neutrino_jukebox_view_add_track( NomadJukebox *jukebox,
-					     guint total_tracks,
-					     const NomadTrack *track,
-					     NeutrinoJukeboxView *view )
+		guint jobid, guint total_tracks,
+		const NomadTrack *track, NeutrinoJukeboxView *view )
 {
 	if( view->jukebox != jukebox ) {
 		return;
@@ -350,8 +346,8 @@ static void neutrino_jukebox_view_add_track( NomadJukebox *jukebox,
 }
 
 static void neutrino_jukebox_view_remove_track( NomadJukebox *jukebox,
-						const NomadTrack *track,
-						NeutrinoJukeboxView *view )
+		guint jobid, const NomadTrack *track,
+		NeutrinoJukeboxView *view )
 {
 	if( view->jukebox != jukebox ) {
 		return;
@@ -363,9 +359,8 @@ static void neutrino_jukebox_view_remove_track( NomadJukebox *jukebox,
 }
 
 static void neutrino_jukebox_view_change_track( NomadJukebox *jukebox,
-						const NomadTrack *orig,
-						const NomadTrack *track,
-						NeutrinoJukeboxView *view )
+		guint jobid, const NomadTrack *orig,
+		const NomadTrack *track, NeutrinoJukeboxView *view )
 {
 	gchar *artist;
 	gchar *album;
@@ -449,9 +444,8 @@ static void neutrino_jukebox_view_change_track( NomadJukebox *jukebox,
 
 
 static void neutrino_jukebox_view_add_playlist( NomadJukebox *jukebox,
-						guint total_tracks,
-						const gchar *name,
-						NeutrinoJukeboxView *view )
+		guint jobid, guint total_tracks, const gchar *name,
+		NeutrinoJukeboxView *view )
 {
 	if( view->jukebox != jukebox ) {
 		return;
@@ -459,8 +453,8 @@ static void neutrino_jukebox_view_add_playlist( NomadJukebox *jukebox,
 }
 
 static void neutrino_jukebox_view_remove_playlist( NomadJukebox *jukebox,
-						   const gchar *name,
-						   NeutrinoJukeboxView *view )
+		guint jobid, const gchar *name,
+		NeutrinoJukeboxView *view )
 {
 	if( view->jukebox != jukebox ) {
 		return;
